@@ -83,24 +83,24 @@ class Point:
 
     @log
     def __init__(self,
-                 user: Union[int, User],
+                 user: Union[int, User, None],
                  query_params: Union[None, dict] = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
                  ):
-        self._user = user if isinstance(user, User) else User.objects.get(id=user)
+        self._user = user if user is None or isinstance(user, User) else User.objects.get(id=user)
         self._cache = None
         self._response = None
         self._is_async = is_async
         self._client = (Request(service=self._point_id.service,
                                 path=self._path,
                                 query_params=query_params,
-                                user=user,
+                                user=self._user,
                                 timeout=timeout,
                                 ) if not is_async else
                         Tasks(service=self._point_id.service,
                               path=self._path,
-                              user=user,
+                              user=self._user,
                               )
                         )
         self.__query_params = query_params
@@ -175,7 +175,7 @@ class ContractPoint(FilterMixin, CacheMixin, Point):
     _sort_by = 'id'
 
     def __init__(self,
-                 user: User = 1,
+                 user: Union[int, User, None] = None,
                  query_params: dict = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30),
